==> avendesora-0.12.0.tar.gz: avendesora-0.12.0/avendesora/collection.py <==
# Collections
#
# Provides common interface for dictionaries and lists. If a string is passed
# in, it is split and then treated as a list. Optimized for convenience rather
# than for large collections. Sorting versus the key is used to avoid randomness
# in the ordering of the dictionary-based collections.

# License {{{1
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/.

# Imports {{{1
from inform import is_str, is_collection

# Collection {{{1
class Collection:
    def __init__(self, collection):
        if is_str(collection):
            self.collection = collection.split()
        elif is_collection(collection):
            self.collection = collection
        else:
            # is scalar
            self.collection = {None, collection}

    def keys(self):
        try:
            return self.collection.keys()
        except AttributeError:
            return range(len(self.collection))

    def values(self):
        try:
            return [self.collection[k] for k in sorted(self.collection.keys())]
        except AttributeError:
            return self.collection

    def items(self):
        try:
            return [(k, self.collection[k]) for k in sorted(self.collection.keys())]
        except AttributeError:
            return enumerate(self.collection)

    def __contains__(self, item):
        return item in self.values()

    def __iter__(self):
        return iter(self.values())

==> avendesora-0.14.8.tar.gz: avendesora-0.14.8/avendesora/collection.py <==
# Collections
#
# Provides common interface for dictionaries and lists. If a string is passed
# in, it is split and then treated as a list. Optimized for convenience rather
# than for large collections. Sorting versus the key is used to avoid randomness
# in the ordering of the dictionary-based collections.

# License {{{1
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/.

# Imports {{{1
from inform import is_str, is_collection

# Collection {{{1
class Collection(object):
    def __init__(self, collection):
        if is_str(collection):
            self.collection = collection.split()
        elif is_collection(collection):
            self.collection = collection
        else:
            # is scalar
            self.collection = {None: collection}

    def keys(self):
        try:
            return self.collection.keys()
        except AttributeError:
            return range(len(self.collection))

    def values(self):
        try:
            return [self.collection[k] for k in sorted(self.collection.keys())]
        except AttributeError:
            return self.collection

    def items(self):
        try:
            return [(k, self.collection[k]) for k in sorted(self.collection.keys())]
        except AttributeError:
            return enumerate(self.collection)

    def __contains__(self, item):
        return item in self.values()

    def __iter__(self):
        return iter(self.values())
